"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var _1 = require(".");
var ctor_ensure_decorator_1 = require("./ctor-ensure.decorator");
var validateCtor = function (className, value) {
    // Find target class
    var Target = ctor_ensure_decorator_1.registry[className];
    if (!Target)
        return null;
    // Get all controls of this class and find the highest validated ctor index
    var ctls = (0, ctor_ensure_decorator_1.getActiveControls)(Target, className, []);
    var maxCtorInd = ctls.reduce(function (acc, curr) { return (curr.ctorInd > acc ? curr.ctorInd : acc); }, 0);
    // Constructor arguments list, map value fields to their indices
    var ctorArgs = new Array(maxCtorInd + 1).fill(undefined);
    ctls.forEach(function (ctl) {
        var currValue = value[ctl.displayName];
        if (!currValue)
            return;
        ctorArgs[ctl.ctorInd] = currValue;
    });
    // Try to instantiate a class, return errors on throw
    try {
        // eslint-disable-next-line no-new
        new (Target.bind.apply(Target, (0, tslib_1.__spreadArray)([void 0], (0, tslib_1.__read)(ctorArgs), false)))();
    }
    catch (err) {
        if (err instanceof _1.CtorEnsureException)
            return err.errors;
    }
    // No errors occurred
    return [];
};
exports.default = validateCtor;
//# sourceMappingURL=ctor-validator.js.map