"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ENSURE_ENUM = exports.enumKeys = exports.enumValues = void 0;
var description_template_factory_1 = require("../../description-template.factory");
var util_1 = require("../../util");
/**
 * Find all string values of a provided enum and make them regex safe
 * @param values Enum type
 * @returns All string values of this enum, escaped
 */
var enumValues = function (values) { return Object.keys(values).filter(function (it) { return Number.isNaN(Number(it)); }).map(function (it) { return (0, util_1.escapeRegExp)(it); }); };
exports.enumValues = enumValues;
/**
 * Find all number keys of a provided enum
 * @param values Enum type
 * @returns All number keys of this enum
 */
var enumKeys = function (values) { return Object.keys(values).filter(function (it) { return !Number.isNaN(Number(it)); }).map(function (it) { return Number.parseInt(it, 10); }); };
exports.enumKeys = enumKeys;
/**
 * Ensure to be used within config of {@link ValidatedArg}
 * Ensure this field is a member of an enum
 * @param values Enum to be checked against
 * @param disallow Whether or not to disallow these values (blocklist)
 * @param useKeys If true, the enum keys (numeric) will be used, otherwise it'll be the string values
 */
var ENSURE_ENUM = function (values, disallow, useKeys) {
    if (disallow === void 0) { disallow = false; }
    if (useKeys === void 0) { useKeys = false; }
    var vals = useKeys ? (0, exports.enumKeys)(values) : (0, exports.enumValues)(values);
    return {
        description: (0, description_template_factory_1.template)('ENSURE_ENUM', {
            numValues: vals.length,
            multiple: vals.length > 1,
            values: vals.join(', '),
            disallow: disallow,
        }),
        process: function (value) { return ({
            error: vals.includes(value) === disallow,
            value: value,
        }); },
    };
};
exports.ENSURE_ENUM = ENSURE_ENUM;
//# sourceMappingURL=enum.validation-ensure.js.map