"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var description_template_factory_1 = require("../../description-template.factory");
/**
 * Ensure to be used within config of {@link ValidatedArg}
 * Ensure this field is an array of values
 * @param positive True if should be an array, false otherwise
 * @param unique Whether or not the array values have to be unique
 * @param ignoreCase Whether or not to ignore casing on compare
 */
var ENSURE_ISARRAY = function (positive, unique, ignoreCase) {
    if (positive === void 0) { positive = true; }
    if (unique === void 0) { unique = false; }
    if (ignoreCase === void 0) { ignoreCase = false; }
    return ({
        description: (0, description_template_factory_1.template)('ENSURE_ISARRAY', {
            positive: positive,
            unique: unique,
            ignoreCase: ignoreCase,
        }),
        process: function (_value, _neighbors, _ctor, _parent, arg) {
            // Not the desired datastructure
            if (!(Array.isArray(arg) === positive))
                return { error: true, value: arg };
            // Check if it's unique, only if it's an array
            if (positive && unique) {
                var seen = [];
                for (var i = 0; i < arg.length; i += 1) {
                    var curr = arg[i];
                    // Ignorecase of course only works with strings
                    if (ignoreCase)
                        curr = String(curr).toLowerCase();
                    // Duplicate value
                    if (seen.includes(curr))
                        return { error: true, value: arg[i] };
                    seen.push(curr);
                }
            }
            // Validation passed
            return { error: false };
        },
    });
};
exports.default = ENSURE_ISARRAY;
//# sourceMappingURL=isarray.validation-ensure.js.map