"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var description_template_factory_1 = require("../../description-template.factory");
/**
 * Ensure to be used within config of {@link ValidatedArg}
 * Ensure this field's content matches with all other provided fields
 * @param positive Whether or not it should match or mismatch (allow-/block)
 * @param fieldName Names of partner fields, need to be registered {@link ValidatedArg}
 */
var ENSURE_EQUALSFIELD = function (positive) {
    var fieldNames = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        fieldNames[_i - 1] = arguments[_i];
    }
    return ({
        description: (0, description_template_factory_1.template)('ENSURE_EQUALSFIELD', {
            numFields: fieldNames.length,
            fieldNames: fieldNames.join(', '),
            disallow: !positive,
        }),
        process: function (value, neighbors, ctor) {
            var _a;
            var _loop_1 = function (i) {
                var name_1 = fieldNames[i];
                var index = (_a = neighbors.find(function (it) { return it.displayName === name_1; })) === null || _a === void 0 ? void 0 : _a.ctorInd;
                // Partner-field not existing
                if (!index)
                    throw SyntaxError('Unknown field requested!');
                // Partner-field mismatched
                var curr = ctor[index];
                if (positive ? (curr !== value || value === undefined) : (curr === value))
                    return { value: { error: true, value: value } };
            };
            for (var i = 0; i < fieldNames.length; i += 1) {
                var state_1 = _loop_1(i);
                if (typeof state_1 === "object")
                    return state_1.value;
            }
            // All passed
            return { error: false };
        },
    });
};
exports.default = ENSURE_EQUALSFIELD;
//# sourceMappingURL=equalsfield.validation-ensure.js.map