"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var description_template_factory_1 = require("../../description-template.factory");
/**
 * Ensure to be used within config of {@link ValidatedArg}
 * Ensure this field has a min and max length, if it's an array, ignore otherwise
 * @param min Mininum amount of elements inside array
 * @param max Maximum amount of elements inside array
 */
var ENSURE_ARRAYSIZE = function (min, max) {
    if (min < 0 && max < 0)
        throw new SyntaxError('Define at least min or max!');
    if (min > max && max !== -1)
        throw new SyntaxError('Max cannot be less than min!');
    return {
        description: (0, description_template_factory_1.template)('ENSURE_ARRAYSIZE', {
            min: min,
            max: max,
            hasMin: min > 0,
            hasMax: max > 0,
            hasBoth: min > 0 && max > 0,
        }),
        process: function (_value, _neighbors, _ctor, _parent, arg) { return ({
            error: (
            // Is not an array
            !Array.isArray(arg) ||
                // or not within specified range
                ((arg.length < min && min > 0) ||
                    (arg.length > max && max > 0))),
            value: arg,
        }); },
    };
};
exports.default = ENSURE_ARRAYSIZE;
//# sourceMappingURL=arraysize.validation-ensure.js.map