"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var description_template_factory_1 = require("../../description-template.factory");
/**
 * Ensure to be used within config of {@link ValidatedArg}
 * Ensure this field's date value is within a specified range
 * @param min Mininum date (including)
 * @param max Maximum date (including)
 */
var ENSURE_MINMAXDATE = function (min, max) {
    var minStamp = (min === null || min === void 0 ? void 0 : min.getTime()) || -1;
    var maxStamp = (max === null || max === void 0 ? void 0 : max.getTime()) || -1;
    if (minStamp === -1 && maxStamp === -1)
        throw new SyntaxError('Define at least min or max!');
    if (minStamp > maxStamp && maxStamp !== -1)
        throw new SyntaxError('Max cannot be less than min!');
    return {
        description: (0, description_template_factory_1.template)('ENSURE_MINMAXDATE', {
            min: min === null || min === void 0 ? void 0 : min.toISOString(),
            max: max === null || max === void 0 ? void 0 : max.toISOString(),
            hasMin: minStamp > -1,
            hasMax: maxStamp > -1,
            hasBoth: minStamp > -1 && maxStamp > -1,
        }),
        process: function (value) { return ({
            error: (
            // Isn't a date
            !(value instanceof Date) ||
                // or not within specified range
                ((value.getTime() > maxStamp && maxStamp > -1) ||
                    (value.getTime() < minStamp && minStamp > -1))),
            value: value,
        }); },
    };
};
exports.default = ENSURE_MINMAXDATE;
//# sourceMappingURL=minmaxdate.validation-ensure.js.map