"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var description_template_factory_1 = require("../../description-template.factory");
/**
 * Ensure to be used within config of {@link ValidatedArg}
 * Constrain the length of a string
 * @param min Minimum length
 * @param max Maximum length
 */
var ENSURE_MINMAXLEN = function (min, max) {
    if (min < 0 && max < 0)
        throw new SyntaxError('Define at least min or max!');
    if (min > max && max !== -1)
        throw new SyntaxError('Max cannot be less than min!');
    var pattern = new RegExp("^.{" + (min > 0 ? min : 0) + "," + (max > 0 ? max : '') + "}$");
    return {
        description: (0, description_template_factory_1.template)('ENSURE_MINMAXLEN', {
            min: min,
            max: max,
            hasMin: min > 0, hasMax: max > 0, hasBoth: min > 0 && max > 0,
        }),
        process: function (value) { return ({
            error: !pattern.test(value),
            value: value,
        }); },
    };
};
exports.default = ENSURE_MINMAXLEN;
//# sourceMappingURL=minmaxlen.validation-ensure.js.map