"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var description_template_factory_1 = require("../../description-template.factory");
/**
 * Ensure to be used within config of {@link ValidatedArg}
 * Ensure this field is only containing ascii characters
 * @param justPrintable Whether or not to just allow visible characters
 * @param allowSpaces Whether or not to allow spaces
 */
var ENSURE_ASCII = function (justPrintable, allowSpaces) {
    if (justPrintable === void 0) { justPrintable = false; }
    if (allowSpaces === void 0) { allowSpaces = true; }
    // eslint-disable-next-line no-control-regex, no-nested-ternary
    var pattern = justPrintable ? (allowSpaces ? /^[ -~]*$/ : /^[!-~]*$/) : (allowSpaces ? /^[\x00-\x7F]*$/ : /^[\x00-\x1F\x21-\x7F]*$/);
    return {
        description: (0, description_template_factory_1.template)('ENSURE_ASCII', {
            onlyprint: justPrintable,
            nospaces: !allowSpaces,
        }),
        process: function (value) { return ({
            error: !pattern.test(value),
            value: value,
        }); },
    };
};
exports.default = ENSURE_ASCII;
//# sourceMappingURL=ascii.validation-ensure.js.map