"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ENSURE_BASEENCODED = exports.Encoding = void 0;
var description_template_factory_1 = require("../../description-template.factory");
// Known base encodings
var Encoding;
(function (Encoding) {
    Encoding[Encoding["BASE32"] = 1] = "BASE32";
    Encoding[Encoding["BASE58"] = 2] = "BASE58";
    Encoding[Encoding["BASE64"] = 3] = "BASE64";
})(Encoding = exports.Encoding || (exports.Encoding = {}));
/**
 * Ensure to be used within config of {@link ValidatedArg}
 * Ensure this field is only containing base X encoded data
 * @param encoding Encoding base to be allowed
 */
var ENSURE_BASEENCODED = function (encoding) {
    var pattern;
    switch (encoding) {
        case Encoding.BASE32:
            pattern = /^(?:[A-Z2-7]{8})*(?:[A-Z2-7]{2}={6}|[A-Z2-7]{4}={4}|[A-Z2-7]{5}={3}|[A-Z2-7]{7}=)?$/;
            break;
        case Encoding.BASE64:
            pattern = /^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$/;
            break;
        case Encoding.BASE58:
            pattern = /^[A-HJ-NP-Za-km-z1-9]*$/;
            break;
        default:
            throw new Error('Unsupported base!');
    }
    return {
        description: (0, description_template_factory_1.template)('ENSURE_BASEENCODED', {
            base: (Encoding[encoding]).toUpperCase(),
        }),
        process: function (value) { return ({
            error: !pattern.test(value),
            value: value,
        }); },
    };
};
exports.ENSURE_BASEENCODED = ENSURE_BASEENCODED;
//# sourceMappingURL=baseencoded.validation-ensure.js.map