"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLastSuperclassProto = exports.escapeRegExp = exports.evalStrThunk = exports.ternaryString = exports.pluralize = exports.strOpt = void 0;
var tslib_1 = require("tslib");
/**
 * Make a string optional, which means it'll be empty when the
 * condition didin't evaluate to true
 * @param str String to optionalize
 * @param state Condition
 * @returns Original string or empty string
 */
var strOpt = function (str, state) { return state ? str : ''; };
exports.strOpt = strOpt;
/**
 * Pluralize a word, based on the corresponding count. Also
 * gets rid of all spaces on the right to properly append
 * @param word Word in singular form
 * @param num Count of type the word describes
 * @param suf Suffix for plural, defaults to s
 * @returns Pluralized word
 */
var pluralize = function (word, num, suf) {
    if (suf === void 0) { suf = 's'; }
    return "" + word.trimRight() + (0, exports.strOpt)(suf, num !== 1);
};
exports.pluralize = pluralize;
/**
 * Shorthand to use a ternary operator on two string parameters
 * @param state Boolean representing state
 * @param ifTrue String for true state
 * @param ifFalse String for false state
 * @returns Either one of the strings
 */
var ternaryString = function (state, ifTrue, ifFalse) { return state ? ifTrue : ifFalse; };
exports.ternaryString = ternaryString;
/**
 * Evaluates a string thunk bei either calling it, if it's a
 * function, or returning it's immediate value
 * @param thunk Either a thunk returning a string or a string value
 * @param args Arguments to be passed to the thunk
 * @returns Evaluated string value
 */
var evalStrThunk = function (thunk) {
    var args = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        args[_i - 1] = arguments[_i];
    }
    return typeof thunk === 'function' ? thunk.apply(void 0, (0, tslib_1.__spreadArray)([], (0, tslib_1.__read)(args), false)) : thunk;
};
exports.evalStrThunk = evalStrThunk;
/**
 * Escape a string to be used within a regular expression safely
 * @param val String to escape
 * @returns Regex-safe string
 */
var escapeRegExp = function (val) { return val.replace(/[.*+?^${}()|[\]\\]/g, '\\$&'); };
exports.escapeRegExp = escapeRegExp;
/**
 * Find the last (highest) super-class prototype, starting from a
 * derived class constructor function
 * @param clazz Derived class to start from
 * @returns Prototype of superclass or undefined when there's no inheritance
 */
var getLastSuperclassProto = function (clazz) {
    var protos = [];
    var curr = clazz;
    // Crawl till' end
    do {
        protos.push(curr);
        curr = Object.getPrototypeOf(curr);
    } while (curr !== null);
    // Get the previous of last, since last is the
    // object prototype (last in chain)
    return protos[protos.length - 2];
};
exports.getLastSuperclassProto = getLastSuperclassProto;
//# sourceMappingURL=util.js.map