"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var ctor_ensure_decorator_1 = require("./ctor-ensure.decorator");
var optionality_enum_1 = (0, tslib_1.__importDefault)(require("./optionality.enum"));
/**
 * Apply one or more validations to a constructor property
 * @param displayName Name of the field to validate
 * @param config Validation config
 * @param optional Whether or not this field is optional
 */
var ValidatedArg = function (displayName, config, optional, skipOn) {
    if (optional === void 0) { optional = optionality_enum_1.default.REQUIRED; }
    return function (clazz, _, index) {
        var _a;
        // Ensure existence of array
        if (!Reflect.hasOwnMetadata(ctor_ensure_decorator_1.META_KEY_VALIDATION, clazz))
            Reflect.defineMetadata(ctor_ensure_decorator_1.META_KEY_VALIDATION, [], clazz);
        // Find entry for current field name and index
        var meta = Reflect.getOwnMetadata(ctor_ensure_decorator_1.META_KEY_VALIDATION, clazz);
        // Find control by ctor parameter index
        var control = meta.find(function (it) { return it.ctorInd === index; });
        // Ensure existence of control for field
        if (!control) {
            control = {
                displayName: displayName,
                ctorInd: index,
                configs: [],
                optional: optional,
                skipOn: skipOn,
            };
            meta.push(control);
        }
        // Add configs to control
        var configs = Array.isArray(config) ? config : [config];
        (_a = control.configs).push.apply(_a, (0, tslib_1.__spreadArray)([], (0, tslib_1.__read)(configs), false));
    };
};
exports.default = ValidatedArg;
//# sourceMappingURL=validated-arg.decorator.js.map